@@ -138,7 +138,7 @@ class UR3Arm(robot_arms.RobotArm):
                          relative: bool = False, wait: bool = True, timeout: Optional[float] = None):
         vel = velocity if velocity is not None else self._default_velocity
         acc = acceleration if acceleration is not None else vel * 2
-        transform = self.robot.csys * math3d.Transform(location.matrix)
+        transform = self.robot.csys * math3d.Transform(location.convert_mm_to_m().matrix)
         distance = self.robot._get_lin_dist(transform.pose_vector)
 
         self.robot.movel(transform.pose_vector, acc=acc / 1000, vel=vel / 1000, relative=relative, wait=False)
